# Security Policy

## Supported Versions

| Version | Supported          |
| ------- | ------------------ |
| 1.0.x   | :white_check_mark: |

## Reporting a Vulnerability

If you discover a security vulnerability, please report it through GitHub Issues with the "security" label.

Please do not report security vulnerabilities through public GitHub issues.

We will respond to security reports within 48 hours.